@@ -1,22 +1,18 @@
 /*
-	ccbuild - A strict developer's build utility
-	Copyright (C) 2005  A. Bram Neijt <bneijt@gmail.com>
+  This file is part of ccbuild.
 
+  ccbuild is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-	This program is free software; you can redistribute it and/or
-	modify it under the terms of the GNU General Public License
-	as published by the Free Software Foundation; either version 2
-	of the License, or (at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  ccbuild is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
+  You should have received a copy of the GNU General Public License
+  along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "Resolver.ih"
@@ -27,11 +23,16 @@ Resolver::Resolver()
   d_empty("")
 {
 	//Load commandline given extra resolution files
-	_foreach(xr, Options::extraResolutions)
+	__foreach(xr, Options::extraResolutions)
 		loadIfExists(*xr, true);//Load if exists, reporting errors
 
 	//Load default
-	loadIfExists("./ccResolutions");
+	//Try username, try hostname dependent, try system name, try architecture dependent, try username, try default
+	loadIfExists("./ccResolutions."+ FBB::User().name())
+	  || loadIfExists("./ccResolutions."+System::uname('n'))
+	  || loadIfExists("./ccResolutions."+System::uname('s'))
+	  || loadIfExists("./ccResolutions."+System::uname('m'))
+	  || loadIfExists("./ccResolutions");
 
 
 	//Load global resolution files
@@ -45,7 +46,7 @@ Resolver::Resolver()
 
 		FileSystem::globFilesInto(&files, "~/.ccbuild/ccResolutions.d/*", true);
 
-		_foreach(file, files)
+		__foreach(file, files)
 			loadIfExists(*file);
 	}
 	
@@ -115,14 +116,14 @@ Resolver::Resolver()
 Resolver::~Resolver()
 {
 	//Todo: cleanup using unique_copy etc.
-	set<std::string *> pointers;
+	set<std::string const*> pointers;
 	
-	_foreach(link, d_staticLinks)
+	__foreach(link, d_staticLinks)
 			pointers.insert((*link).second);
 
 	pointers.erase(&d_empty);
 	
-	_foreach(pointer, pointers)
+	__foreach(pointer, pointers)
 		delete (*pointer);
 	
 }
