@@ -1,22 +1,20 @@
 /*
-	ccbuild - A strict developer's build utility
-	Copyright (C) 2005  A. Bram Neijt <bneijt@gmail.com>
+  This file is part of ccbuild.
 
-	This program is free software; you can redistribute it and/or
-	modify it under the terms of the GNU General Public License
-	as published by the Free Software Foundation; either version 2
-	of the License, or (at your option) any later version.
+  ccbuild is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  ccbuild is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
+  You should have received a copy of the GNU General Public License
+  along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
+
 #include "Resolver.ih"
 
 namespace {
@@ -33,9 +31,10 @@ bool hasSpaces(char const *w)
 
 string Resolver::expand(std::string const &name) const
 {
-#ifdef __CYGWIN__
-	return name;
-#elif defined(__APPLE_C__) or defined(__APPLE__)
+#if defined(__CYGWIN__) or defined(__APPLE_C__) or defined(__APPLE__)
+  //TODO Replace this with sh -c 'for i;do echo $i;done' dummy HELLO HOW ARE YOU
+  //TODO   to make sure that it handles quoted arguments correctly. Then it can
+  //TODO   very probably become the default.
 	ostringstream pathstr("", ios::app);
 	string echo("echo " + name);
 	ostringstream os;
