@@ -1,26 +1,24 @@
 /*
-	ccbuild - A strict developer's build utility
-	Copyright (C) 2005  A. Bram Neijt <bneijt@gmail.com>
+  This file is part of ccbuild.
 
-	This program is free software; you can redistribute it and/or
-	modify it under the terms of the GNU General Public License
-	as published by the Free Software Foundation; either version 2
-	of the License, or (at your option) any later version.
+  ccbuild is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  ccbuild is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
+  You should have received a copy of the GNU General Public License
+  along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include <iomanip>
+
 #include "Resolver.ih"
-void Resolver::loadIfExists(std::string const &confFile, bool report)
+bool Resolver::loadIfExists(std::string const &confFile, bool report)
 {
+
 	//Load a configuration file if it exists
   ifstream file(confFile.c_str());
   _debugLevel1("Loading: '" << confFile << "'");
@@ -34,7 +32,7 @@ void Resolver::loadIfExists(std::string const &confFile, bool report)
   	_debugLevel1("Unable to open: " << confFile);
   	if(report)
   		cerr << "ccbuild: Unable to open: '" << confFile << "'\n";
-  	return;
+  	return false;
   }
 
 	unsigned linenr=0;
@@ -58,20 +56,14 @@ void Resolver::loadIfExists(std::string const &confFile, bool report)
     //Find a seperating tab
     string::size_type i = line.find_first_of("\t");
 
-    if(i == string::npos)
-    {
-    	//Try to recover with a space seperation
+    if(i == string::npos) //Try to recover with a space seperation
 	    i = line.find_first_of(" ");
-	    if(i == string::npos)
-	    {
-	    	cerr << "ccbuild: Error: Non empty configuration line " << linenr << " without space or tab character,\n";
-	    	cerr << "ccbuild: Error: in file:  '" << confFile << "'.\n";
-	      continue;
-			}
-		}
 
 		global = line.substr(0, i);
-		arguments = line.substr(i + 1);
+
+		arguments = "";
+		if(i != string::npos)
+  		arguments = line.substr(i + 1);
 
 		System::trim(&global);
 		System::trim(&arguments);
@@ -95,8 +87,13 @@ void Resolver::loadIfExists(std::string const &confFile, bool report)
   }
 
   file.close();
-  
+
+  if(Options::verbose)
+    cerr << "Loaded resolutions file: " << confFile << "\n";
+
+
 	//Clean up expand cache??
 	//NO The pointer part is stored in d_staticLinks
 	// and will be deleted when the Resolver is destroyed.
+	return true;
 }
