@@ -1,23 +1,22 @@
 /*
-   ccbuild - A strict developer's build utility
+  ccbuild - A strict developer's build utility
+  Copyright (C) 2008  A. Bram Neijt <bneijt@gmail.com>
 
-   Copyright (C) 2005 A. Bram Neijt <bneijt@gmail.com>
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
+
 /**\file
 
  \brief ccbuild - A strict developer's build utility
@@ -41,16 +40,17 @@
   </pre>
 */
 
-#include "System/System.hh"
-#include "Source/Source.hh"
-#include "FileSystem/FileSystem.hh"
-
-#include "Misc/Preprocessor/Foreach.hh"
-#include "Options/Options.hh"
+#include "problem/problem.hh"
+#include "system/system.hh"
+#include "source/source.hh"
+#include "fileSystem/fileSystem.hh"
+#include "globallocks/globallocks.hh"
+#include "misc/foreach.hh"
+#include "options/options.hh"
 
 //Singletons...
-#include "Arguments/Arguments.hh"
-#include "Sources/Sources.hh"
+#include "arguments/arguments.hh"
+#include "sources/sources.hh"
 #include "MD5Info/MD5Info.hh"
 
 
@@ -64,7 +64,7 @@
 #include <typeinfo>
 
 //#define DEBUGLEVEL 20
-#include "Misc/Preprocessor/Debug.hh"
+#include "misc/debug.hh"
 
 using namespace bneijt;
 using namespace std;
@@ -117,6 +117,7 @@ class ArgsDestroy
 int main(int argc, char **argv)
 try
 {
+  //TODO Clean up main
   //See Options/statics.cc Options::CC = "g++";
   //See Options/statics.cc Options::version = "...";
   Arguments::Option options[] = {
@@ -127,6 +128,7 @@ try
     {"compiler", "<cmd>", "Set the compiler command (Default: g++)"},
     {"a args", "<arguments>", "Use these as base compiler arguments (Default: -Wall -g)"},
     {"C", "<path>", "Change directory before anything else"},
+    {"cachedir", "<path>", "Set the path of the object/metadata cache directory (Default: o)"},
     {"p precompile-ih", "", "Precompile only internal headers (g++-3.4 up)"},
     {"precompile-all", "", "Precompile all headers (g++-3.4 up)"},
     {"brute", "", "Continue on compiler errors"},
@@ -143,11 +145,15 @@ try
     {"nodefres", "", "Don't load any ccResolutions files but ./ccResolutions"},
     {"addres", "<file>", "Also load this resolution file"},
     {"pversion", "<version>", "Set the program version you are working on (used by the lib command)"},
-    {"ar", "", "Archive before link [EXPERIMENTAL]"},
+    {"ar", "", "Archive before link (can shrink size for release)"},
     {"verbose", "", "Show executed commands and produce more output for dot and check commands"},
     {"V version", "", "Output ccbuild version number to stdout"},
     {"xml", "", "Where supported, produce XML output"},
     {"nowarn", "", "Leave out most warnings"},
+    {"batch", "", "Batch multiple source files into one g++ statement (very experimental, may not work with -I yet)"},
+#ifdef _OPENMP
+    {"j", "<integer>", "Set the maximum number of threads used during build"},
+#endif
     {"", "", ""}	//End of list
   };
 
@@ -178,6 +184,7 @@ try
 
   if(Options::showCommands)
   {
+    cerrLock.set();
     cerr << "Command:";
     for(int i = 0; i < argc; i++)
     {
@@ -187,6 +194,7 @@ try
         cerr << " " << argv[i];
     }
     cerr << "\n";
+    cerrLock.unset();
   }
 
   if(destroy)
@@ -230,7 +238,7 @@ try
     cerr << "Implicit build\n";
     rest.push_back("build");
   }  
-  else if(rest.size() == 1 && FileSystem::fileExists(*rest.begin()))
+  else if(rest.size() == 1 && FileSystem::fileExists(*rest.begin(), /*noDir=*/true))
   {
     cerr << "Implicit build because first an only command is a file\n";
     rest.insert(rest.begin(), "build");    	
@@ -241,7 +249,7 @@ try
   Sources &sources = Sources::getInstance();
   
   bool skipArgument(false);
-  _foreach(argument, rest)
+  __foreach(argument, rest)
   {
     vector<string>::iterator next = argument;
     ++next;
@@ -499,30 +507,6 @@ try
       retValue = 0;
       break;
     }
-    else if(*argument == "tree")
-    {
-      cerr << "[" << *argument << "]\n";
-
-      if(next == rest.end())
-        System::tree(cout);
-      else
-      {
-        Source *s = sources[*next];
-        if(s)
-        {
-          skipArgument = true;
-          System::tree(s, cout);
-        }
-        else
-        {
-          cerr << "Error loading '" <<  *next << "' as tree source.\n";
-          retValue = 2;
-          break;
-        }
-      }
-      retValue = 0;
-      break;
-    }
     else if(*argument == "dot")
     {
       cerr << "[" << *argument << "]\n";
@@ -590,7 +574,7 @@ try
   
   return retValue;
 }
-catch(const Problem &p)
+catch(const bneijt::Problem &p)
 {
 	cerr << "ccbuild: Problem " << p.id() << ": " << p.what() << "\n";
   System::destroy();
@@ -601,4 +585,41 @@ catch(const std::exception &e)
 	//All is LOST... nothing to do here but die
   cerr << "Caught std::exception (" << typeid(e).name() << "): " << e.what();
   cerr << "\nPlease report this as a bug.\n";
+  return 1;
 }
+/////Problem with OpenMP and exception catching
+//ccbuild: Non zero exit status (1)
+//terminate called after throwing an instance of 'bneijt::Problem'
+//  what():  Compilation failed on Behavior/GuardGoal/generateGoal.cc
+
+//Program received signal SIGABRT, Aborted.
+//[Switching to Thread 0x7ffff6020910 (LWP 8920)]
+//0x00007ffff68934b5 in *__GI_raise (sig=<value optimized out>)
+//    at ../nptl/sysdeps/unix/sysv/linux/raise.c:64
+//64	../nptl/sysdeps/unix/sysv/linux/raise.c: No such file or directory.
+//	in ../nptl/sysdeps/unix/sysv/linux/raise.c
+//Current language:  auto
+//The current source language is "auto; currently c".
+//(gdb) bt
+//#0  0x00007ffff68934b5 in *__GI_raise (sig=<value optimized out>)
+//    at ../nptl/sysdeps/unix/sysv/linux/raise.c:64
+//#1  0x00007ffff6896f50 in *__GI_abort () at abort.c:92
+//#2  0x00007ffff7132cc5 in __gnu_cxx::__verbose_terminate_handler() ()
+//   from /usr/lib/libstdc++.so.6
+//#3  0x00007ffff71310f6 in ?? () from /usr/lib/libstdc++.so.6
+//#4  0x00007ffff712ffe9 in ?? () from /usr/lib/libstdc++.so.6
+//#5  0x00007ffff7130a91 in __gxx_personality_v0 () from /usr/lib/libstdc++.so.6
+//#6  0x00007ffff6bdf6e3 in ?? () from /lib/libgcc_s.so.1
+//#7  0x00007ffff6bdf7a8 in _Unwind_Resume () from /lib/libgcc_s.so.1
+//#8  0x0000000000438300 in bneijt::Source::buildObjectTarget (this=0x6d1b00, 
+//    cc=...) at source/buildObjectTarget.cc:59
+//#9  0x00000000004457d4 in bneijt::Source::build (this=0x6d1b00, cc=...)
+//    at source/build.cc:36
+//#10 0x000000000042beb8 in bneijt::System::build (.omp_data_i=0x7fffffffd8f0)
+//    at system/build.cc:150
+//#11 0x00007ffff7bd99c2 in ?? () from /usr/lib/libgomp.so.1
+//#12 0x00007ffff664aa04 in start_thread (arg=<value optimized out>)
+//    at pthread_create.c:300
+//#13 0x00007ffff693f7bd in clone ()
+//    at ../sysdeps/unix/sysv/linux/x86_64/clone.S:112
+//#14 0x0000000000000000 in ?? ()
